# Threat Stack Application Security

Python version of the [Threat Stack](https://www.threatstack.com) agent which helps identify security vulnerabilities at runtime.

# Installation

Refer detailed instructions on how to install the Threat Stack agent [here](https://threatstack.zendesk.com/hc/en-us/articles/360039993431).
